# DAPC K-Means Clustering, Andrew Gottscho, 01/29/16
# Using Western Uma dataset. 597 ?? unlinked SNPs.

#load library adegenet
library(adegenet)

#read dataset from structure file
data <- read.structure("output_western_uma_121214_n60_h5_p75_editnames_2.str", n.ind=64, n.loc=597, onerowperind=FALSE, col.lab=1, col.pop=0, col.others=NULL, row.marknames=NULL, NA.char="-9", pop=NULL, ask=FALSE, quiet=FALSE) 

#K-means clustering. Number of PCAS: 64, number of clusters: 5
clusters<-find.clusters(data, clust=NULL, n.pca=NULL, n.clust=NULL, stat=c("BIC","AIC", "WSS"), choose.n.clust=TRUE, criterion=c("diffNgroup", "min","goesup", "smoothNgoesup", "goodfit"), max.n.clust=10, n.iter=1e5, n.start=10, scale=FALSE, truenames=TRUE)

# DAPC. Number of PCAs: 20, number of DA's: 4
results<-dapc(data, pop=clusters$grp, n.pca=NULL, n.da=NULL, scale=FALSE, truenames=TRUE, var.contrib=TRUE, pca.info=TRUE, pca.select=c("nbEig","percVar"), perc.pca=NULL)

#SCATTERPlot DAPC
scatter.dapc(results, xax=1, yax=2, grp=results$grp, col=seasun(length(levels(results$grp))),
                       pch=20, bg="white", solid=.7, scree.da=TRUE,
                       scree.pca=FALSE, posi.da="bottomright",
                       posi.pca="bottomleft", bg.inset="white", ratio.da=.25,
                       ratio.pca=.25, inset.da=0.02, inset.pca=0.02,
                       inset.solid=.5, onedim.filled=TRUE, mstree=FALSE, lwd=1,
                       lty=1, segcol="black", legend=FALSE, posi.leg="topright",
                       cleg=1, txt.leg=levels(results$grp), cstar = 1, cellipse = 1.5,
                       axesell = FALSE, label = levels(results$grp), clabel = 1, xlim =
                       NULL, ylim = NULL, grid = FALSE, addaxes = TRUE, origin =
                       c(0,0), include.origin = TRUE, sub = "", csub = 1, possub =
                       "bottomleft", cgrid = 1, pixmap = NULL, contour = NULL, area
                       = NULL)

#Another assignment plot
assignplot(results, only.grp=NULL, subset=NULL, new.pred=NULL, cex.lab=.5,pch=3)

#Another plot
compoplot(results, only.grp=NULL, subset=NULL, new.pred=NULL, col=NULL, lab=NULL,
          legend=TRUE, txt.leg=NULL, ncol=4, posi=NULL, cleg=.8, bg=transp("white"))
